import 'package:flutter/material.dart';
import 'package:flutter_pull_refresh_sdk/flutter_pull_refresh_sdk.dart';

class PullRefreshTest extends StatefulWidget {
  final bool refreshEnable;
  final bool loadMoreEnable;
  final RefreshController refreshController;
  final VoidCallback onRefreshListener;
  final VoidCallback onLoadMoreListener;
  final Widget child;
  final int loadStatus;

  PullRefreshTest(
      {this.refreshEnable: true,
      this.loadMoreEnable: true,
      @required this.refreshController,
      this.onRefreshListener,
      this.onLoadMoreListener,
      this.loadStatus,
      @required this.child});
  @override
  _PullRefreshTest createState() => _PullRefreshTest();
}

class _PullRefreshTest extends State<PullRefreshTest> with SingleTickerProviderStateMixin{
  AnimationController controller;
  CurvedAnimation curved; //曲线动画，动画插值，
  
  @override
  void initState() {
    super.initState();
    controller =
        AnimationController(duration: const Duration(seconds: 1), vsync: this);
    curved = new CurvedAnimation(
        parent: controller, curve: Curves.decelerate); //模仿小球自由落体运动轨迹
    controller.forward();
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        //动画从 controller.forward() 正向执行 结束时会回调此方法
        //print("status is completed");
        //重置起点
        controller.reset();
        //开启
        controller.forward();
      } else if (status == AnimationStatus.dismissed) {
        // controller.reverse();
        //动画从 controller.reverse() 反向执行 结束时会回调此方法
        //print("status is dismissed");
      } else if (status == AnimationStatus.forward) {
        //print("status is forward");
        //执行 controller.forward() 会回调此状态
      } else if (status == AnimationStatus.reverse) {
        //执行 controller.reverse() 会回调此状态
        //print("status is reverse");
      }
    });
  }
  
  @override
  void dispose() {
    super.dispose();
  }
  @override
  Widget build(BuildContext context) {
    return PullRefresh(
      refreshController: widget.refreshController,
      onRefreshListener: widget.onRefreshListener,
      onLoadMoreListener: widget.onLoadMoreListener,
      child: widget.child,
      headerRefreshing: buildRotationTransition(),
      headeRidle: logoIcon(),
      headerRelease: logoIcon(),
      headerComplete: logoIcon(),
      headerCompleteText: '刷新完成',
      headerRefreshingText: '刷新中',
      headerIdleText: '松开刷新1',
      headerReleaseText: '松开刷新2',
      footerNoDataText: '-------我是有底线的-------',
      footerLoadingText:'加载更多1',
      footerCanLoadingText:'加载更多2',
      footerIdleText:'加载更多3',
      footerFailedText:'加载失败',
      footerCanLoading: buildRotationTransition(),
      loadStatus: widget.loadStatus,
      );
  }
  ///旋转
  Widget buildRotationTransition() {
    return RotationTransition(
      //旋转动画
      turns: curved,
      child: Image.asset(
        'images/dgg_pulldown_15.png',
        width: 28,
        height: 28,
      ),
    );
  }
  Widget logoIcon() {
    return Image.asset(
        'images/dgg_pulldown_15.png',
        width: 28,
        height: 28,
      );
  }
}